@@ -3,7 +3,7 @@
 config = {
 
     #Indicate the web API that HiTyper should call to invoke the DL model
-    "type4py": "http://0.0.0.0:23333/api/predict?tc=0",
+    "type4py": "https://type4py.com/api/predict?tc=0",
 
     #Indicate the default DL model used in HiTyper
     "default_model": "type4py",
@@ -26,4 +26,4 @@ config = {
 
     #Indicate the path of stored tokenizer if you use a huggingface address aabove
     "cached_dir": "./transformers"
-}
\ No newline at end of file
+}
